// Sample data structure for celebrity rankings
const celebrityData = [
  {
    name: "Taylor Swift",
    rank: 1,
    scores: {
      overall: 98,
      charts: 100,
      streams: 95,
      sales: 100,
      impact: 97
    },
    image: "taylor-swift.jpg"
  }
  // Add more celebrities here
];

// DOM Elements
const menuToggle = document.querySelector('.menu-toggle');
const navLinks = document.querySelector('.nav-links');
const rankingGrid = document.querySelector('.ranking-grid');
const filterButtons = document.querySelectorAll('.ranking-filters button');

// Mobile menu toggle
menuToggle.addEventListener('click', () => {
  navLinks.classList.toggle('active');
});

// Filter button functionality
filterButtons.forEach(button => {
  button.addEventListener('click', () => {
    // Remove active class from all buttons
    filterButtons.forEach(btn => btn.classList.remove('active'));
    // Add active class to clicked button
    button.classList.add('active');
    // Update rankings based on selected filter
    updateRankings(button.dataset.filter);
  });
});

// Function to update rankings based on filter
function updateRankings(filter = 'overall') {
  rankingGrid.innerHTML = '';
  
  const sortedCelebrities = [...celebrityData].sort((a, b) => {
    return b.scores[filter] - a.scores[filter];
  });

  sortedCelebrities.forEach((celebrity, index) => {
    const celebrityCard = document.createElement('div');
    celebrityCard.className = 'celebrity-card';
    celebrityCard.innerHTML = `
      <div class="rank">#${index + 1}</div>
      <h3>${celebrity.name}</h3>
      <div class="score">${celebrity.scores[filter]}</div>
    `;
    rankingGrid.appendChild(celebrityCard);
  });
}

// Initialize rankings with overall score
document.addEventListener('DOMContentLoaded', () => {
  updateRankings('overall');
});

// Smooth scroll for navigation links
document.querySelectorAll('a[href^="#"]').forEach(anchor => {
  anchor.addEventListener('click', function (e) {
    e.preventDefault();
    document.querySelector(this.getAttribute('href')).scrollIntoView({
      behavior: 'smooth'
    });
  });
});
